package com.example.blum.artfromjson;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

public class MainActivity extends AppCompatActivity {

    //declare a global JSONarray -- the array of objects we will get from reading the JSON file
    JSONArray myJSON_array;

    //keep track of the selected painter and painting using an index
    int painterIndex=0;
    int paintingIndex =0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        final Spinner spPainting = (Spinner) findViewById(R.id.spPainting);
        Spinner spPainter = (Spinner) findViewById(R.id.spArtist);

        try{
            //http://stackoverflow.com/questions/6420293/reading-android-raw-text-file
            InputStream is = getResources().openRawResource(R.raw.painting_data);
            byte[] buffer = new byte[is.available()];
            while (is.read(buffer) != -1);

            String myText = new String(buffer);
            //Toast.makeText(getBaseContext(), "Got here", Toast.LENGTH_LONG).show();
            //http://stackoverflow.com/questions/9605913/how-to-parse-json-in-android
            //extract the main (top-level) JSON object from the file read above
            JSONObject myJSON_object = new JSONObject(myText);

            //the main JSON object is/includes an array called painters
            //extract that array
            myJSON_array = myJSON_object.getJSONArray("painters");

            //create a String array of horse rank and name -- used to populate spinner
            String[] artist_name = new String[myJSON_array.length()];
            for (int i=0; i < myJSON_array.length(); i++){
                try{
                    //get an individual element of the JSON array
                    JSONObject aJSON_element = myJSON_array.getJSONObject(i);
                    //get the individual properties of the JSON element
                    String first_name = aJSON_element.getString("firstName");
                    String last_name = aJSON_element.getString("lastName");
                    //make the artist full name
                    artist_name[i] = first_name + ". " + last_name;
                }
                catch (JSONException e)
                {
                    Toast.makeText(getBaseContext(), "Dude, you have to know what the JSON looks like to parse it",
                            Toast.LENGTH_SHORT).show();
                    e.printStackTrace();
                } //end try-catch of JSON decodding file and making artist array
            }

            //associate the artist full name with the listView
            ArrayAdapter<String> aaPainter = new ArrayAdapter<String>(this,   android.R.layout.simple_spinner_item,
                    artist_name);
            aaPainter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item); // The drop down view
            spPainter.setAdapter(aaPainter);

            //when user choses and artist
            spPainter.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
                @Override
                public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {

                    painterIndex =i;

                    TextView tvBirth = (TextView) findViewById(R.id.tvBirth);
                    TextView tvDeath = (TextView) findViewById(R.id.tvDeath);
                    TextView tvCountry = (TextView) findViewById(R.id.tvCountry);

                    TextView tvUserItem = (TextView) view;
                    Toast.makeText(getApplicationContext(), "You chose "+tvUserItem.getText().toString() ,
                            Toast.LENGTH_SHORT).show();
                    try {
                        tvBirth.setText("  " + myJSON_array.getJSONObject(i).getString("birthDate"));
                        tvDeath.setText("  to          " + myJSON_array.getJSONObject(i).getString("deathDate"));
                        tvCountry.setText("  " + myJSON_array.getJSONObject(i).getString("countryName"));

                        JSONArray artistPaintings = myJSON_array.getJSONObject(i).getJSONArray("paintings");

                        // the file has a different number of paintings for various artists
                        // so use list instead of array
                        List<String> painting_titles = new ArrayList<String>();
                        for(int k=0; k<artistPaintings.length(); k++){
                            try {
                                JSONObject aPainting = artistPaintings.getJSONObject(k);
                                painting_titles.add( aPainting.getString("title"));
                            }catch(JSONException e){

                            }
                        }

                        spPainting.setAdapter(null);  //clears spinner of any old paintings from previous artist

                        ArrayAdapter<String> aaPainting = new ArrayAdapter<String>(getBaseContext(),
                                android.R.layout.simple_spinner_item, painting_titles);
                        aaPainting.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item); // The drop down view
                        spPainting.setAdapter(aaPainting);

                        //when the user chose a painting of the selected artist
                        spPainting.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
                            @Override
                            public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
                                TextView tvUserChoice = (TextView) view;
                                //Toast.makeText(getApplicationContext(), "You chose "+tvUserChoice.getText().toString() , Toast.LENGTH_SHORT).show();

                                paintingIndex =i;

                                try {
                                    //get the selected artist's selected painting
                                    String paintingFilename = myJSON_array.getJSONObject(painterIndex).getJSONArray("paintings").getJSONObject(paintingIndex).getString("filename");
                                    Toast.makeText(getApplicationContext(), "You chose "+  paintingFilename, Toast.LENGTH_SHORT).show();

                                    ImageView ivPainting = (ImageView) findViewById(R.id.ivPainting);
                                    //eliminate file extension
                                    paintingFilename = paintingFilename.substring(0, paintingFilename.lastIndexOf('.'));
                                    //replace any dash with underscore
                                    paintingFilename = paintingFilename.replace("-", "_");
                                    //put into all lower case
                                    paintingFilename = paintingFilename.toLowerCase();
                                    int iv_id = getResources().getIdentifier(paintingFilename, "drawable",
                                            getPackageName());
                                    ivPainting.setImageResource(iv_id);
                                }catch(JSONException e){
                                }//end of try-catch for painting JSON decode
                            }//end of onItemSelected of Painting spinner

                            @Override
                            public void onNothingSelected(AdapterView<?> adapterView) {
                            }
                        });// end of setOnItemSelectedListener


                    }catch(Exception e){

                    }
                }

                @Override
                public void onNothingSelected(AdapterView<?> adapterView) {
                }
            });// end of Painter setOnItemSelectedListener

        }
        catch(Exception e){
            Toast.makeText(getBaseContext(), "Problem with file", Toast.LENGTH_LONG).show();
            e.printStackTrace();
        } //end try-catch of reading file

    }//end onCreat
}//end MainActivity

